Area class abstract

Inheritance

Constructors

Area(dynamic data)

Properties

currentRoom Room?
getter/setter pair
exists bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
listData ↔ dynamic
getter/setter pair
messages List
getter/setter pairinherited
newMessages int
getter/setter pairinherited
occupantMap Map<UniqueName, dynamic>
getter/setter pairinherited
options Map<String, dynamic>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
latefinalinherited

Methods

getOccupant(UniqueName name) → dynamic
inherited
getOccupantName(UniqueName name) String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseOccupantName(Map<String, dynamic> data) String
inherited
toString() String
A string representation of this object.
inherited
updateArea(Map<String, dynamic> data) bool
updateOccupants(Map<String, dynamic> data) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited